@@ -1,16 +1,15 @@
+#![feature(nll)]
+
+pub use backing::backing_file::BackingFile;
+pub use epoch::Epoch;
+pub use frame::Frame;
+pub use quotick::Quotick;
+pub use tick::Tick;
+
 pub mod backing;
 pub mod epoch;
-pub mod epoch_bridge;
 pub mod frame;
-pub mod frameset;
 pub mod path_builder;
 pub mod quotick;
 pub mod tick;
 
-pub use backing::backing_file::BackingFile;
-pub use backing::random_access_file::RandomAccessFile;
-pub use epoch::Epoch;
-pub use frame::Frame;
-pub use frameset::FrameSet;
-pub use quotick::Quotick;
-pub use tick::Tick;
